<?php

/***************************************************************************
 * 
 *  Name: Events Calendar
 *  URI: http://jcore.net
 *  Description: A small events calendar to allow your members to post events with a link to more details about the event.
 *  Author: Istvan Petres
 *  Version: 0.1
 *  Tags: events calendar, month calendar, gpl
 * 
 ****************************************************************************/

include_once('lib/calendar.class.php');
@include_once('lib/monthcalendar.class.php');

modules::register(
	'eventsCalendar', 
	'Events Calendar',
	'Lets you display events in a calendar system.');
	
class eventsMonthCalendar extends monthCalendar {
	function __construct() {
		parent::__construct();
		
		$this->uriRequest = 'modules/eventscalendar/'.$this->uriRequest;
	}
	
	function displayDay($time) {
		if (date('Y-m-d', $time) >= date('Y-m-d', time())) 
			echo
				"<a href='".url::uri('add, edit, '.$this->variable) .
					"&amp;".$this->variable."=".$time .
					"&amp;add=1" .
					"&amp;request=modules/eventscalendar' " .
					"class='events-calendar-add ajax-content-link'>" .
				"</a>";
		
		parent::displayDay($time);
		
		$rows = sql::run(
			" SELECT * FROM `{eventscalendar}`" .
			" WHERE `StartTimeStamp` < '".date('Y-m-d H:i:s', $time+60*60*24)."'" .
			" AND `EndTimeStamp` > '".date('Y-m-d H:i:s', $time)."'" .
			" ORDER BY `StartTimeStamp` ASC, `ID`");
			
		while($row = sql::fetch($rows)) {
			echo
				"<div class='events-calendar-event'>";
				
			if ($GLOBALS['USER']->loginok && ($GLOBALS['USER']->data['Admin'] || 
				$GLOBALS['USER']->data['ID'] == $row['UserID']))
			{
				echo
					"<a href='".url::uri('add, edit, '.$this->variable) .
						"&amp;".$this->variable."=".$time .
						"&amp;edit=".$row['ID'] .
						"&amp;request=modules/eventscalendar' " .
						"class='events-calendar-edit ajax-content-link'>" .
					"</a>";
			}
			
			echo
				"<a" .
					($row['URL']?
						" href='".$row['URL']."'":
						null) .
					($row['Cancelled']?
						" style='text-decoration: line-through;'":
						null).
					" target='_blank'>" .
					"<span title='" .
						($row['Cancelled']?
							_("Cancelled")."! ":
							null).
						htmlspecialchars(
							calendar::dateTime($row['StartTimeStamp']) .
							" -> " .
							calendar::dateTime($row['EndTimeStamp']),
							ENT_QUOTES) .
						($row['URL']?
							"\n".$row['URL']:
							null) .
						"' class='tip'>" .
						stripslashes($row['Title']) .
					"</span>" .
				"</a>" .
				"</div>";
		}
	}
}

class eventsCalendar extends modules {
	var $selectedID;
	var $ajaxRequest = false;
	var $adminPath = 'admin/modules/eventscalendar';
	
	function __construct() {
		languages::load('eventscalendar');
	}
	
	function __destruct() {
		languages::loadMessages();
	}
	
	function SQL() {
		return
			" SELECT * FROM `{eventscalendar}`" .
			" WHERE !`Deactivated`" .
			" ORDER BY `StartTimeStamp` DESC, `ID`";
	}
	
	function installSQL() {
		sql::run(
			" CREATE TABLE IF NOT EXISTS `{eventscalendar}` (" .
			" `ID` smallint(5) unsigned NOT NULL auto_increment," .
			" `Title` varchar(255) NOT NULL," .
			" `URL` varchar(255) NOT NULL," .
			" `StartTimeStamp` timestamp NOT NULL default CURRENT_TIMESTAMP," .
			" `EndTimeStamp` timestamp NOT NULL," .
			" `Cancelled` tinyint(1) unsigned NOT NULL default '0'," .
			" `UserID` mediumint(8) unsigned NOT NULL default '1'," .
			" PRIMARY KEY  (`ID`)," .
			" KEY `UserID` (`UserID`, `StartTimeStamp`, `EndTimeStamp`, `Cancelled`)" .
			" ) ENGINE=MyISAM;");
		
		if (sql::display())
			return false;
		
		return true;
	}
	
	function installFiles() {
		$css = 
			".events-calendar-event {\n" .
			"	padding: 3px 5px;\n" .
			"	border: 1px solid #338ead;\n" .
			"	background: #50b1d4;\n" .
			"	text-align: left;\n" .
			"}\n" .
			"\n" .
			".events-calendar-event a {\n" .
			"	display: block;\n" .
			"	color: #ffffff;\n" .
			"	text-decoration: none;\n" .
			"}\n" .
			"\n" .
			".events-calendar-event a:hover {\n" .
			"	color: #ffffff;\n" .
			"	text-decoration: underline;\n" .
			"}\n" .
			"\n" .
			".events-calendar-add {\n" .
			"	display: block;\n" .
			"	float: left;\n" .
			"	width: 16px;\n" .
			"	height: 16px;\n" .
			"	background: url(\"http://icons.jcore.net/16/add.png\") no-repeat;\n" .
			"}\n" .
			"\n" .
			".events-calendar-edit {\n" .
			"	display: block;\n" .
			"	float: right;\n" .
			"	width: 16px;\n" .
			"	height: 16px;\n" .
			"	background: url(\"http://icons.jcore.net/16/pencil.png\") no-repeat;\n" .
			"}\n" .
			"\n" .
			".events-calendar .calendar-day {\n" .
			"	height: 70px;\n" .
			"}\n" .
			"\n" .
			".admin-section-item.as-modules-eventscalendar a {\n" .
			"	background-image: url(\"http://icons.jcore.net/48/evolution-calendar.png\");\n" .
			"}\n";
		
		if (!files::save(SITE_PATH.'template/modules/css/eventscalendar.css', $css, true)) {
			tooltip::display(
				_("Could NOT write css file. Please make sure that " .
					"template/modules/css is writable by me."),
				'error');
			return false;
		}
		
		return true;
	}
	
	// ************************************************   Admin Part
	function countAdminItems() {
		if (!parent::installed($this))
			return 0;
		
		$row = sql::fetch(sql::run(
			" SELECT COUNT(*) AS `Rows`" .
			" FROM `{eventscalendar}`" .
			" LIMIT 1"));
		return $row['Rows'];
	}
	
	function setupAdmin() {
		if ($this->userPermissionType == USER_PERMISSION_TYPE_WRITE)
			favoriteLinks::add(
				_('New Event'), 
				'?path='.admin::path().'#adminform');
	}
	
	function setupAdminForm(&$form) {
		$form->add(
			_('Event'),
			'Title',
			FORM_INPUT_TYPE_TEXT,
			true);
		$form->setStyle('width: 350px;');
		
		$form->add(
			__('Link to URL'),
			'URL',
			FORM_INPUT_TYPE_TEXT);
		$form->setStyle('width: 300px;');
		
		$form->add(
			_('Starts on'),
			'StartTimeStamp',
			FORM_INPUT_TYPE_TIMESTAMP,
			true);
		$form->setStyle('width: 170px;');
		$form->setValueType(FORM_VALUE_TYPE_TIMESTAMP);
		
		$form->add(
			_('Ends on'),
			'EndTimeStamp',
			FORM_INPUT_TYPE_TIMESTAMP,
			true);
		$form->setStyle('width: 170px;');
		$form->setValueType(FORM_VALUE_TYPE_TIMESTAMP);
		
		$form->add(
			_('Cancelled'),
			'Cancelled',
			FORM_INPUT_TYPE_CHECKBOX,
			false,
			'1');
		$form->setValueType(FORM_VALUE_TYPE_BOOL);
		
		$form->addAdditionalText(
			"<span class='comment' style='text-decoration: line-through;'>" .
			__("(marked with strike through)").
			"</span>");	
	}
	
	function verifyAdmin(&$form = null) {
		$delete = null;
		$edit = null;
		$id = null;
		
		if (isset($_GET['delete']))
			$delete = $_GET['delete'];
		
		if (isset($_GET['edit']))
			$edit = $_GET['edit'];
		
		if (isset($_GET['id']))
			$id = (int)$_GET['id'];
		
		if ($delete) {
			if (!$this->delete($id))
				return false;
				
			tooltip::display(
				_("Event has been successfully deleted."),
				TOOLTIP_SUCCESS);
			
			return true;
		}
		
		if (!$form->verify())
			return false;
		
		if (strtotime($form->get('EndTimeStamp')) < strtotime($form->get('StartTimeStamp'))) {
			tooltip::display(
				_("Event cannot have end time set to before start time!"),
				TOOLTIP_ERROR);
			return false;
		}
		
		if ($edit) {
			if (!$this->edit($id, $form->getPostArray()))
				return false;
				
			tooltip::display(
				_("Event has been successfully updated.")." " .
				(modules::getOwnerURL('eventsCalendar')?
					"<a href='".eventsCalendar::getURL().
						"' target='_blank'>" .
						_("View Calendar") .
					"</a>" .
					" - ":
					null) .
				"<a href='#adminform'>" .
					__("Edit") .
				"</a>",
				TOOLTIP_SUCCESS);
			
			return true;
		}
		
		if (!$this->add($form->getPostArray()))
			return false;
				
		tooltip::display(
			_("Event has been successfully created.") .
			(modules::getOwnerURL('eventsCalendar')?
				"<a href='".eventsCalendar::getURL().
					"' target='_blank'>" .
					_("View Calendar") .
				"</a>":
				null),
			TOOLTIP_SUCCESS);
			
		$form->reset();
		return true;
	}
	
	function displayAdminListHeader() {
		echo
			"<th><span class='nowrap'>".
				_("Title / URL")."</span></th>" .
			"<th><span class='nowrap'>".
				_("Starts on")."</span></th>" .
			"<th><span class='nowrap'>".
				_("Ends on")."</span></th>";
	}
	
	function displayAdminListHeaderOptions() {
	}
	
	function displayAdminListHeaderFunctions() {
		echo
			"<th><span class='nowrap'>".
				__("Edit")."</span></th>" .
			"<th><span class='nowrap'>".
				__("Delete")."</span></th>";
	}
	
	function displayAdminListItem(&$row) {
		echo
			"<td class='auto-width' " .
				($row['Cancelled']?
					"style='text-decoration: line-through;' ":
					null).
				">" .
				"<a href='".
				url::uri('id, edit, delete') .
					"&amp;id=".$row['ID']."' " .
					"class='bold'>" .
				stripslashes($row['Title']) .
				"</a> " .
				"<div class='comment' style='padding-left: 10px;'>" .
					stripslashes($row['URL']) .
				"</div>" .
			"</td>" .
			"<td align='center'>" .
				"<span class='nowrap'>" .
				calendar::datetime($row['StartTimeStamp']) .
				"</span>" .
			"</td>" .
			"<td align='center'>" .
				"<span class='nowrap'>" .
				calendar::datetime($row['EndTimeStamp']) .
				"</span>" .
			"</td>";
	}
	
	function displayAdminListItemOptions(&$row) {
	}
	
	function displayAdminListItemFunctions(&$row) {
		echo
			"<td>" .
				"<a class='admin-link edit' " .
					"title='".__("Edit")."' " .
					"href='".url::uri('id, edit, delete') .
					"&amp;id=".$row['ID']."&amp;edit=1#adminform'>" .
				"</a>" .
			"</td>" .
			"<td>" .
				"<a class='admin-link delete confirm-link' " .
					"title='".__("Delete")."' " .
					"href='".url::uri('id, edit, delete') .
					"&amp;id=".$row['ID']."&amp;delete=1'>" .
				"</a>" .
			"</td>";
	}
	
	function displayAdminListItemSelected(&$row) {
		$user = $GLOBALS['USER']->get($row['UserID']);
		
		admin::displayItemData(
			_("Added by"),
			$GLOBALS['USER']->constructUserName($user));
		
		if ($row['URL'])
			admin::displayItemData(
				_("Website"),
				"<a href='".
					$row['URL']."' target='_blank'>".
					$row['URL'] .
				"</a>");
	}
	
	function displayAdminListSearch() {
		$search = null;
		
		if (isset($_GET['search']))
			$search = trim(strip_tags($_GET['search']));
		
		echo
			"<input type='hidden' name='path' value='".admin::path()."' />" .
			"<input type='search' name='search' value='".
				htmlspecialchars($search, ENT_QUOTES).
				"' results='5' placeholder='".htmlspecialchars(__("search..."), ENT_QUOTES)."' /> " .
			"<input type='submit' value='" .
				htmlspecialchars(__("Search"), ENT_QUOTES)."' class='button' />";
	}
	
	function displayAdminList($rows) {
		$id = null;
		
		if (isset($_GET['id']))
			$id = (int)$_GET['id'];
		
		echo "<table cellpadding='0' cellspacing='0' class='list'>" .
				"<thead>" .
				"<tr class='lheader'>";
			
		$this->displayAdminListHeader();
		$this->displayAdminListHeaderOptions();
				
		if ($this->userPermissionType == USER_PERMISSION_TYPE_WRITE)
			$this->displayAdminListHeaderFunctions();
				
		echo
				"</tr>" .
				"</thead>" .
				"<tbody>";
		
		$i = 0;		
		while($row = sql::fetch($rows)) {
			echo 
				"<tr".($i%2?" class='pair'":NULL).">";
				
			$this->displayAdminListItem($row);
			$this->displayAdminListItemOptions($row);
					
			if ($this->userPermissionType == USER_PERMISSION_TYPE_WRITE)
				$this->displayAdminListItemFunctions($row);
			
			echo
				"</tr>";
			
			if ($row['ID'] == $id) {
				echo
					"<tr".($i%2?" class='pair'":NULL).">" .
						"<td class='auto-width' colspan='10'>" .
							"<div class='admin-content-preview'>";
				
				$this->displayAdminListItemSelected($row);
				
				echo
							"</div>" .
						"</td>" .
					"</tr>";
			}
			
			$i++;
		}
		
		echo 
				"</tbody>" .
			"</table>" .
			"<br />";
		
		return true;
	}
	
	function displayAdminForm(&$form) {
		$form->display();
	}

	function displayAdminTitle($ownertitle = null) {
		admin::displayTitle(
			_('Events Calendar Administration'),
			$ownertitle);
	}
	
	function displayAdminDescription() {
	}
	
	function displayAdmin() {
		if (modules::displayAdmin())
			return;
		
		$search = null;
		$edit = null;
		$id = null;
		
		if (isset($_GET['search']))
			$search = trim(strip_tags($_GET['search']));
		
		if (isset($_GET['edit']))
			$edit = $_GET['edit'];
		
		if (isset($_GET['id']))
			$id = (int)$_GET['id'];
			
		echo
			"<div style='float: right;'>" .
				"<form action='".url::uri('ALL')."' method='get'>";
		
		$this->displayAdminListSearch();
		
		echo
				"</form>" .
			"</div>";
		
		$this->displayAdminTitle();
		$this->displayAdminDescription();
		
		echo
			"<div class='admin-content'>";
				
		$form = new form(
				($edit?
					_("Edit Event"):
					_("New Event")),
				'neweditevent');
		
		if (!$edit)
			$form->action = url::uri('id, delete, limit');
					
		$this->setupAdminForm($form);
		$form->addSubmitButtons();
		
		if ($edit) {
			$form->add(
				__('Cancel'),
				'cancelbutton',
				 FORM_INPUT_TYPE_BUTTON);
			$form->addAttributes("onclick=\"window.location='".
				str_replace('&amp;', '&', url::uri('id, edit, delete'))."'\"");
		}
		
		$verifyok = false;
		
		if ($this->userPermissionType == USER_PERMISSION_TYPE_WRITE &&
			(!$this->userPermissionIDs || ($edit && 
				in_array($id, explode(',', $this->userPermissionIDs)))))
		{
			$verifyok = $this->verifyAdmin($form);
		}
		
		$paging = new paging(20);
		$paging->ignoreArgs = 'id, edit, delete';
		
		$rows = sql::run(
			" SELECT * FROM `{eventscalendar}`" .
			" WHERE 1" .
			($this->userPermissionIDs?
				" AND `ID` IN (".$this->userPermissionIDs.")":
				null) .
			($search?
				sql::search(
					$search,
					array('Title')):
				null) .
			" ORDER BY `StartTimeStamp` DESC, `ID`" .
			" LIMIT ".$paging->limit);
		
		$paging->setTotalItems(sql::count());
		
		if ($paging->items)
			$this->displayAdminList($rows);
		else
			tooltip::display(
					_("No events found."),
					'notification');
		
		$paging->display();
		
		if ($this->userPermissionType == USER_PERMISSION_TYPE_WRITE &&
			(!$this->userPermissionIDs || ($edit && 
				in_array($id, explode(',', $this->userPermissionIDs)))))
		{
			if ($edit && $id && ($verifyok || !$form->submitted())) {
				$row = sql::fetch(sql::run(
					" SELECT * FROM `{eventscalendar}` " .
					" WHERE `ID` = '".$id."'" .
					($this->userPermissionIDs?
						" AND `ID` IN (".$this->userPermissionIDs.")":
						null)));
				
				$form->setValues($row);
			}
			
			echo
				"<a name='adminform'></a>";
			
			$this->displayAdminForm($form);
		}
		
		unset($form);
		
		echo 
			"</div>";	//admin-content
	}
	
	function add($values) {
		if (!is_array($values))
			return false;
		
		$newid = sql::run(
			" INSERT INTO `{eventscalendar}` SET ".
			" `Title` = '".
				addslashes($values['Title'])."'," .
			" `URL` = '".
				addslashes($values['URL'])."'," .
			" `StartTimeStamp` = " .
				($values['StartTimeStamp']?
					"'".addslashes($values['StartTimeStamp'])."'":
					"NOW()").
				"," .
			" `EndTimeStamp` = " .
				($values['EndTimeStamp']?
					"'".addslashes($values['EndTimeStamp'])."'":
					"DATE_ADD(NOW(), INTERVAL 1 DAY)").
				"," .
			" `Cancelled` = '".
				($values['Cancelled']?
					'1':
					'0').
				"'," .
			" `UserID` = '".
				(int)$GLOBALS['USER']->data['ID']."'");
		
		if (!$newid) {
			tooltip::display(
				sprintf(_("Event couldn't be created! Error: %s"), 
					sql::error()),
				TOOLTIP_ERROR);
			return false;
		}
		
		return $newid;
	}
	
	function edit($id, $values) {
		if (!$id)
			return false;
		
		if (!is_array($values))
			return false;
		
		sql::run(
			" UPDATE `{eventscalendar}` SET ".
			" `Title` = '".
				addslashes($values['Title'])."'," .
			" `URL` = '".
				addslashes($values['URL'])."'," .
			" `StartTimeStamp` = " .
				($values['StartTimeStamp']?
					"'".addslashes($values['StartTimeStamp'])."'":
					"NOW()").
				"," .
			" `EndTimeStamp` = " .
				($values['EndTimeStamp']?
					"'".addslashes($values['EndTimeStamp'])."'":
					"DATE_ADD(NOW(), INTERVAL 1 DAY)").
				"," .
			" `Cancelled` = '".
				($values['Cancelled']?
					'1':
					'0').
				"'" .
			" WHERE `ID` = '".(int)$id."'");
		
		if (sql::affected() == -1) {
			tooltip::display(
				sprintf(_("Event couldn't be updated! Error: %s"), 
					sql::error()),
				TOOLTIP_ERROR);
			return false;
		}
		
		return true;
	}
	
	function delete($id) {
		if (!$id)
			return false;
		
		sql::run(
			" DELETE FROM `{eventscalendar}` " .
			" WHERE `ID` = '".(int)$id."'");
		
		return true;
	}
	
	// ************************************************   Client Part
	static function getURL($id = 0) {
		$url = modules::getOwnerURL('eventscalendar', $id);
		
		if (!$url)
			return SITE_URL.'?';
		
		return $url;	
	}
	
	function verify(&$form) {
		$delete = null;
		$edit = null;
		
		if (isset($_GET['delete']))
			$delete = $_GET['delete'];
		
		if (isset($_GET['edit']))
			$edit = (int)$_GET['edit'];
		
		if (isset($_POST['deletebutton']) && $_POST['deletebutton']) {
			if (!$this->delete($edit))
				return false;
				
			tooltip::display(
				_("Event has been successfully deleted."),
				TOOLTIP_SUCCESS);
			
			return true;
		}
		
		if (!$form->verify())
			return false;
			
		if (!$GLOBALS['USER']->loginok) {
			tooltip::display(
				_("Please login first!"),
				TOOLTIP_ERROR);
			return false;
		}
		
		if (strtotime($form->get('EndTimeStamp')) < strtotime($form->get('StartTimeStamp'))) {
			tooltip::display(
				_("Event cannot have end time set to before start time!"),
				TOOLTIP_ERROR);
			return false;
		}
		
		if ($edit) {
			if (!$this->edit($edit, $form->getPostArray()))
				return false;
				
			tooltip::display(
				_("Event has been successfully updated."),
				TOOLTIP_SUCCESS);
			
			return true;
		}
		
		$exists = sql::fetch(sql::run(
			" SELECT `ID` FROM `{eventscalendar}`" .
			" WHERE `Title` = '".addslashes($form->get('Title'))."'" .
			" AND `URL` = '".addslashes($form->get('URL'))."'" .
			" AND `StartTimeStamp` = '".addslashes($form->get('StartTimeStamp'))."'" .
			" AND `EndTimeStamp` = '".addslashes($form->get('EndTimeStamp'))."'" .
			" LIMIT 1"));
		
		if ($exists) {
			tooltip::display(
				_("Event already exists! Maybe you pressed refresh and resubmitted your previous event.") .
					" <a href='".url::uri('add')."'>"._("Refresh Calendar")."</a>.",
				TOOLTIP_ERROR);
			return false;
		}
		
		if (!$this->add($form->getPostArray()))
			return false;
				
		tooltip::display(
			_("Event has been successfully created."),
			TOOLTIP_SUCCESS);
			
		$form->reset();
		return true;
	}
	
	function setupForm(&$form) {
		$time = time();
		
		if (isset($_GET['eventsmonthcalendartime']))
			$time = $_GET['eventsmonthcalendartime'];
		
		$form->add(
			_('Event'),
			'Title',
			FORM_INPUT_TYPE_TEXT,
			true);
		$form->setStyle('width: 350px;');
		
		$form->add(
			__('Link to URL'),
			'URL',
			FORM_INPUT_TYPE_TEXT);
		$form->setStyle('width: 300px;');
		
		$form->add(
			_('Starts on'),
			'StartTimeStamp',
			FORM_INPUT_TYPE_TIMESTAMP,
			true,
			date('Y-m-d H:i:s', $time));
		$form->setStyle('width: 170px;');
		$form->setValueType(FORM_VALUE_TYPE_TIMESTAMP);
		
		$form->add(
			_('Ends on'),
			'EndTimeStamp',
			FORM_INPUT_TYPE_TIMESTAMP,
			true,
			date('Y-m-d H:i:s', $time+60*60*24));
		$form->setStyle('width: 170px;');
		$form->setValueType(FORM_VALUE_TYPE_TIMESTAMP);
		
		$form->add(
			_('Cancelled'),
			'Cancelled',
			FORM_INPUT_TYPE_CHECKBOX,
			false,
			'1');
		$form->setValueType(FORM_VALUE_TYPE_BOOL);
		
		$form->addAdditionalText(
			"<span class='comment' style='text-decoration: line-through;'>" .
			__("(marked with strike through)").
			"</span>");	
	}
	
	function ajaxRequest() {
		$add = null;
		$edit = null;
		
		if (isset($_GET['add']))
			$add = $_GET['add'];
		
		if (isset($_GET['edit']))
			$edit = $_GET['edit'];
		
		if ($add) {
			$this->displayAddForm();
			return true;
		}
		
		if ($edit) {
			$this->displayEditForm();
			return true;
		}
		
		return true;
	}
	
	function displayAddForm() {
		if (!$GLOBALS['USER']->loginok) {
			if ($this->ajaxRequest)
				$GLOBALS['USER']->displayQuickLogin();
			else
				$GLOBALS['USER']->displayLogin();
			return;
		}
		
		$form = new form(
			_("New Event"), 
			'neweditevent');
		$form->action = url::uri('request, ajax');
		
		$this->setupForm($form);
		$form->addSubmitButtons();
		
		if (!$this->ajaxRequest) {
			$form->add(
				__('Cancel'),
				'cancelbutton',
				 FORM_INPUT_TYPE_BUTTON);
			$form->addAttributes("onclick=\"window.location='".
				str_replace('&amp;', '&', url::uri('add, edit, request, ajax'))."'\"");
		}
		
		if (!$this->verify($form))
			$form->display();
		
		unset($form);
	}
	
	function displayEditForm() {
		if (!$GLOBALS['USER']->loginok) {
			if ($this->ajaxRequest)
				$GLOBALS['USER']->displayQuickLogin();
			else
				$GLOBALS['USER']->displayLogin();
			return;
		}
		
		$row = sql::fetch(sql::run(
			" SELECT * FROM `{eventscalendar}`" .
			" WHERE `ID` = '".(int)$_GET['edit']."'" .
			" LIMIT 1"));
		
		if (!$row) {
			tooltip::display(
				_("Event cannot be found!"),
				'error');
			return;
		}
		
		$form = new form(
			_("Edit Event"),
			'neweditevent');
		$form->action = url::uri('request, ajax');
		
		$this->setupForm($form);
		$form->addSubmitButtons();
		
		$form->add(
			__('Delete'),
			'deletebutton',
			 FORM_INPUT_TYPE_SUBMIT);
		$form->addAttributes("onclick=\"return confirm('" .
			_("Are you sure you want to delete this event?!")."');\"");
		
		if (!$this->ajaxRequest) {
			$form->add(
				__('Cancel'),
				'cancelbutton',
				 FORM_INPUT_TYPE_BUTTON);
			$form->addAttributes("onclick=\"window.location='".
				str_replace('&amp;', '&', url::uri('time, add, edit, request, ajax'))."'\"");
		}
		
		if (!$form->submitted())
			$form->setValues($row);
		
		if (!$this->verify($form))
			$form->display();
		
		unset($form);
	}
	
	function displayArguments() {
		if (!$this->arguments)
			return false;
		
		return false;
	}
	
	function display() {
		if ($this->displayArguments())
			return true;
		
		$add = null;
		$edit = null;
		
		if (isset($_GET['add']))
			$add = $_GET['add'];
		
		if (isset($_GET['edit']))
			$edit = $_GET['edit'];
		
		if ($add) {
			$this->displayAddForm();
			echo "<p></p>";
		}
		
		if ($edit) {
			$this->displayEditForm();
			echo "<p></p>";
		}
		
		echo 
			"<div class='events-calendar'>";
		
		$calendar = new eventsMonthCalendar();
		$calendar->display();
		unset($calendar);
		
		echo
			"</div>";
	}
}

?>